@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -72,7 +72,7 @@ bool TransportPluginManagerPrivate::initializePlugins()
         return true;
     }
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("mailtransport"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QStringLiteral("MailTransport/Plugin"));
+        return md.serviceTypes().contains(QLatin1String("MailTransport/Plugin"));
     });
 
     QVectorIterator<KPluginMetaData> i(plugins);
